@@ -2,8 +2,8 @@
 
     Copyright (C) 2000 Stefan Westerfeld
                        stefan@space.twc.de
-                  2001 Matthias Kretz
-                       kretz@kde.org
+                  2001, 2002 Matthias Kretz
+                             kretz@kde.org
 
     This library is free software; you can redistribute it and/or
     modify it under the terms of the GNU Library General Public
@@ -42,16 +42,18 @@ void FaderIntMapper::valueChanged(int pos)
 	impl->valueChanged(pos);
 }
 
-KFader_impl::KFader_impl(KFader *newKFader /* = 0 */)
-	: KWidget_impl(kfader = (newKFader?newKFader:new KFader(0,100,1,0)))
+KFader_impl::KFader_impl( KFader * widget )
+	: KWidget_impl( widget ? widget : new KFader( 0, 100, 1, 0 ) )
 {
-	kfader->setMinimumWidth(40);
-	kfader->setMinimumHeight(100);
-	new FaderIntMapper(this, kfader);
 	_min = 0; _max = 1; _value = 0;
 	_factor = 1;
 	_logarithmic = 0;
 	_range = 100;
+
+	_kfader = static_cast<KFader*>( _qwidget );
+	_kfader->setMinimumWidth( 40 );
+	_kfader->setMinimumHeight( 100 );
+	new FaderIntMapper( this, _kfader );
 }
 
 string KFader_impl::caption()
@@ -62,7 +64,7 @@ string KFader_impl::caption()
 void KFader_impl::caption(const string& newText)
 {
 	_caption = QString::fromUtf8(newText.c_str());
-	kfader->setName(_caption.utf8().data());
+	_kfader->setName(_caption.utf8().data());
 }
 
 string KFader_impl::color()
@@ -76,7 +78,7 @@ void KFader_impl::color(const string& newColor)
     if(strlen(_color.c_str()))
     {
         QColor qc(_color.c_str());
-        kfader->setColor(qc);
+        _kfader->setColor(qc);
     }
 }
 
@@ -110,7 +112,7 @@ void KFader_impl::max(float newMax)
 
 float KFader_impl::value()
 {
-	//float ret = ( _max + _min - float(kfader->value()) ) / _factor;
+	//float ret = ( _max + _min - float(_kfader->value()) ) / _factor;
 	//if(_logarithmic > 0)
 		//ret = convertFromLog(ret);
 	float ret = _value;
@@ -181,8 +183,8 @@ void KFader_impl::applyValue()
 	int imin = int(_factor * dmin);
 	int imax = int(_factor * dmax);
 	int ivalue = int(_factor * (dmax + dmin - dvalue));
-	kfader->setRange(imin, imax);
-	kfader->setValue(ivalue);
+	_kfader->setRange(imin, imax);
+	_kfader->setValue(ivalue);
 }
 
 void KFader_impl::logarithmic(float newLogarithmic)
@@ -200,3 +202,5 @@ float KFader_impl::logarithmic()
 }
 
 REGISTER_IMPLEMENTATION(KFader_impl);
+
+// vim: sw=4 ts=4
