@@ -11,28 +11,15 @@
 #include <qlineedit.h>
 
 /**
- * Load up the wizard with the playlist string.  Save it if OK is hit.
- */
-void EncoderConfig::playlistWizard(){
-  fileWizard wizard(this, "Playlist File FormatWizard", true);
-  wizard.playlistFormat->setText(kcfg_playlistFileFormat->text());
-  // Show dialog and save results if ok is pressed.
-  bool okClicked = wizard.exec();
-  if(okClicked){
-    kcfg_playlistFileFormat->setText(wizard.playlistFormat->text());
-  }
-}
-
-/**
- * Load up the wizard with the encoder playlist string.  Save it if OK is hit.
+ * Load up the wizard with the encoder fileFormat string.  Save it if OK is hit.
  */
 void EncoderConfig::encoderWizard(){
   fileWizard wizard(this, "Encoder File Format Wizard", true);
-  wizard.playlistFormat->setText(kcfg_fileFormat->text());
+  wizard.fileFormat->setText(kcfg_fileFormat->text());
 
   // Show dialog and save results if ok is pressed.
   bool okClicked = wizard.exec();
   if(okClicked){
-    kcfg_fileFormat->setText(wizard.playlistFormat->text());
+    kcfg_fileFormat->setText(wizard.fileFormat->text());
   }
 }
