@@ -568,7 +568,7 @@ void kmidFrame::file_SaveLyrics()
   if (stat(QFile::encodeName(filename), &statbuf)!=-1)
   {
     QString s = i18n("File %1 already exists\nDo you want to overwrite it?").arg(filename);
-    if (KMessageBox::warningYesNo(this,s)==1)
+    if (KMessageBox::warningYesNo(this,s,QString::null,i18n("Overwrite"),KStdGuiItem::cancel())==1)
       return;
   }
 
