@@ -29,6 +29,8 @@
 #include <noatun/pref.h>
 #include <noatun/plugin.h>
 
+class KAction;
+
 class HTMLExport : public QObject, public Plugin
 {
 Q_OBJECT
@@ -42,7 +44,7 @@ private:
 	QString htmlEscape(const QString &source);
 	QString getColorByEntry(QString s);
 	KConfig *config;
-	int menuID;
+	KAction *mAction;
 
 private slots:
 	void slotExport();
@@ -55,7 +57,7 @@ Q_OBJECT
 public:
 	Prefs(QObject *parent);
 	virtual void save();
-    virtual void reopen();
+	virtual void reopen();
 
 	QGroupBox* colorBox;
 
