@@ -70,13 +70,13 @@ MilkChocolate::MilkChocolate() : QWidget(0,"NoatunUI"), UserInterface()
 		mLoop->setFixedSize(buttonSize,buttonSize);
 		mLoop->setPixmap(BarIcon("noatunloopnone"));
 		connect(mLoop, SIGNAL(clicked()), napp->player(), SLOT(loop()));
-		QToolTip::add(mLoop, i18n("Change Loop Style"));
+		QToolTip::add(mLoop, i18n("Change loop style"));
 
 		mPopup=new QPushButton(this);
 		mPopup->setFixedSize(buttonSize,buttonSize);
 		mPopup->setPixmap(BarIcon("noatun"));
 		connect(mPopup, SIGNAL(clicked()), SLOT(popup()));
-//		QToolTip::add(mRemoveCurrent, i18n("Remove Current File from Playlist"));
+//		QToolTip::add(mRemoveCurrent, i18n("Remove current file from playlist"));
 
 	}
 
@@ -163,7 +163,7 @@ void MilkChocolate::showEvent(QShowEvent*e)
 void MilkChocolate::dragEnterEvent(QDragEnterEvent *event)
 {
     // accept uri drops only
-    event->accept(QUriDrag::canDecode(event));
+    event->accept(KURLDrag::canDecode(event));
 }
 
 void MilkChocolate::dropEvent(QDropEvent *event)
